<?php
/**
 * TA Business functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package TA_Business
 */

if ( ! function_exists( 'ta_business_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function ta_business_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on TA Business, use a find and replace
		 * to change 'ta-business' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'ta-business', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );
        add_theme_support( 'woocommerce' );
    	add_theme_support( 'wc-product-gallery-zoom' );
    	add_theme_support( 'wc-product-gallery-lightbox' );
    	add_theme_support( 'wc-product-gallery-slider' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
        add_image_size('ta-business-slider-image',1920,1000,true);
        add_image_size('ta-business-feature-post-image',1170,700,true);
        add_image_size('ta-business-blog-feature-image',440,320,true);
        add_image_size('ta-business-portfolio-image-1',300,252,true);
        add_image_size('ta-business-portfolio-image-2',300,525,true);
        add_image_size('ta-business-portfolio-image-3',573,232,true);
        add_image_size('ta-business-service-image',40,40,true);
        add_image_size('ta-business-team-image',400,400,true);
        add_image_size('ta-business-team-2-image',400,450,true);
        add_image_size('ta-business-test-image',100,100,true);
        add_image_size('ta-business-client-image',250,100,true);

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'ta-business-primary-menu' => esc_html__( 'Primary Menu', 'ta-business' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'ta_business_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 90,
			'width'       => 350,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'ta_business_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function ta_business_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'ta_business_content_width', 640 );
}
add_action( 'after_setup_theme', 'ta_business_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function ta_business_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar Right', 'ta-business' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'ta-business' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
    
    register_sidebar( array(
		'name'          => esc_html__( 'Sidebar Left', 'ta-business' ),
		'id'            => 'ta-business-sidebar-left',
		'description'   => esc_html__( 'Add widgets here.', 'ta-business' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
    
    register_sidebar( array(
		'name'          => esc_html__( 'Header Cart List', 'ta-business' ),
		'id'            => 'ta-business-header-cart-list',
		'description'   => esc_html__( 'Add widgets here.', 'ta-business' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
    
    register_sidebar( array(
		'name'          => esc_html__( 'Footer Newsletter', 'ta-business' ),
		'id'            => 'ta-business-footer-newsletter',
		'description'   => esc_html__( 'Add widgets here.', 'ta-business' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
    
    register_sidebar( array(
		'name'          => esc_html__( 'Footer One', 'ta-business' ),
		'id'            => 'ta-business-footer-one',
		'description'   => esc_html__( 'Add widgets here.', 'ta-business' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
    
    register_sidebar( array(
		'name'          => esc_html__( 'Footer Two', 'ta-business' ),
		'id'            => 'ta-business-footer-two',
		'description'   => esc_html__( 'Add widgets here.', 'ta-business' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
    
    register_sidebar( array(
		'name'          => esc_html__( 'Footer Three', 'ta-business' ),
		'id'            => 'ta-business-footer-three',
		'description'   => esc_html__( 'Add widgets here.', 'ta-business' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h2 class="widget-title">',
		'after_title'   => '</h2>',
	) );
}
add_action( 'widgets_init', 'ta_business_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function ta_business_scripts() {
    
    $suffix = ( defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ) ? '' : '.min';

    $ta_business_font_query_args = array( 'family' => 'Open+Sans:400,500,600,700|Karla:100,300,400,600' );
    wp_enqueue_style( 'ta-business-google-fonts', add_query_arg( $ta_business_font_query_args, "//fonts.googleapis.com/css" ) );
    wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome/css/font-awesome'.$suffix.'.css' );
    wp_enqueue_style( 'lightbox', get_template_directory_uri() . '/js/lightbox/css/lightbox'.$suffix.'.css' );
    wp_enqueue_style( 'owl-carousel', get_template_directory_uri() . '/js/OwlCarousel/owl.carousel'.$suffix.'.css' );
    wp_enqueue_style( 'slick', get_template_directory_uri() . '/js/slick/slick'.$suffix.'.css' );
    wp_enqueue_style( 'slick-theme', get_template_directory_uri() . '/js/slick/slick-theme'.$suffix.'.css' );
    wp_enqueue_style( 'dscountdown',get_template_directory_uri(). '/js/countdown/dscountdown'.$suffix.'.css' );
    
    if( ta_business_is_woocommerce_activate() ){
	    wp_enqueue_style( 'ta-business-woocommerce-style',get_template_directory_uri(). '/woocommerce/ta-business-woocommerce-style'.$suffix.'.css');
	}
	wp_enqueue_style( 'ta-business-style', get_stylesheet_uri() );
    wp_enqueue_style( 'ta-business-responsive', get_template_directory_uri() . '/css/responsive'.$suffix.'.css');
    
    
    wp_enqueue_script( 'jquery-waypoints', get_template_directory_uri() . '/js/waypoints/jquery.waypoints'.$suffix.'.js', array( 'jquery' ), '2.0.5', true );
    wp_enqueue_script( 'isotope-pkgd', get_template_directory_uri() . '/js/isotope/isotope.pkgd'.$suffix.'.js', array('jquery'));
    wp_enqueue_script( 'packery-mode-pkgd', get_template_directory_uri() . '/js/isotope/packery-mode.pkgd'.$suffix.'.js', array('jquery'));    
    wp_enqueue_script( 'theia-sticky-sidebar',get_template_directory_uri().'/js/theia-sticky-sidebar/theia-sticky-sidebar'.$suffix.'.js',array('jquery'));
    wp_enqueue_script( 'lightbox', get_template_directory_uri() . '/js/lightbox/js/lightbox'.$suffix.'.js',array('jquery') );
	wp_enqueue_script( 'owl-carousel', get_template_directory_uri() . '/js/OwlCarousel/owl.carousel'.$suffix.'.js',array('jquery') );
    wp_enqueue_script( 'slick', get_template_directory_uri() . '/js/slick/slick'.$suffix.'.js',array('jquery') );
    wp_enqueue_script( 'dscountdown',get_template_directory_uri() . '/js/countdown/dscountdown'.$suffix.'.js',array('jquery'));
    wp_enqueue_script( 'counterup', get_template_directory_uri() . '/js/counterup/counterup'.$suffix.'.js', array( 'jquery' ), '1.0', true );
    wp_enqueue_script( 'superfish', get_template_directory_uri() . '/js/superfish'.$suffix.'.js', array( 'jquery' ), '1.0', true );
    wp_enqueue_script( 'ta-business-navigation', get_template_directory_uri() . '/js/navigation'.$suffix.'.js', array(), '20151215', true );
	wp_enqueue_script( 'ta-business-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix'.$suffix.'.js', array(), '20151215', true );
    wp_enqueue_script( 'ta-business-script', get_template_directory_uri() . '/js/ta-business-script'.$suffix.'.js', array('jquery','imagesloaded'));

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'ta_business_scripts',100);

function ta_business_customizer_enqueue(){
    wp_enqueue_script( 'jquery-ui-button' );
    wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome/css/font-awesome.min.css' );
    wp_enqueue_style( 'ta-business-customizer-style', get_template_directory_uri() . '/inc/customizer/css/customizer-style.css' );
    wp_enqueue_script( 'ta-business-customizer-script', get_template_directory_uri() . '/inc/customizer/js/customizer-script.js', array( 'jquery', 'customize-controls' ), '20160714', true );
}
add_action('customize_controls_enqueue_scripts','ta_business_customizer_enqueue');

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Sanitize Function.
 */
require get_template_directory() . '/inc/ta-business-sanitize-functions.php';

/**
 * TA Business Function.
 */
require get_template_directory() . '/inc/ta-business-function.php';

/**
 * TA Business Function.
 */
require get_template_directory() . '/inc/ta-business-metabox.php';

/**
 * TA Business Plugin Activation.
 */
require get_template_directory() . '/inc/tgmpa/plugins.php';

/**
 * TA Business Woocommerce.
 */
if( ta_business_is_woocommerce_activate() ){
	require get_template_directory() . '/woocommerce/ta-business-woocommerce-function.php';
}