<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @package TA_Business
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link rel="profile" href="<?php echo esc_url('http://gmpg.org/xfn/11'); ?>">
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

<?php
if( function_exists('wp_body_open') ){
    wp_body_open();
}
?>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'ta-business' ); ?></a>
    
    <?php ta_business_top_header(); ?>

    <?php $ta_business_main_header_layout = get_theme_mod('ta_business_main_header_layout','layout-1'); ?>
	<header id="masthead" class="site-header <?php echo esc_attr( $ta_business_main_header_layout ); ?>">
        <div class="tab-container">
            <div class="secondary-masthead">

        		<div class="site-branding">
                    
                    <?php if( function_exists( 'has_custom_logo' ) && has_custom_logo() ){ ?>
                    
                        <a href="<?php echo esc_url( home_url( '/' ) ); ?>"> <?php the_custom_logo(); ?></a>
                		
                    <?php } else{ ?>
            				
                        <h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                        
            			<?php $description = get_bloginfo( 'description', 'display' );
            			if ( $description || is_customize_preview() ) : ?>
                        
            				<p class="site-description"><?php echo esc_html($description); /* WPCS: xss ok. */ ?></p>
                            
            			<?php
       			        endif;
                    }?>
        		</div><!-- .site-branding -->
        
        		<nav id="site-navigation" class="main-navigation">
                
        			<div id="toggle">
                        <span class="one"></span>
                        <span class="two"></span>
                        <span class="three"></span>
                    </div>
                    
        			<?php
        				wp_nav_menu( array(
        					'theme_location' => 'ta-business-primary-menu',
        					'menu_id'        => 'primary-menu',
                            'fallback_cb'    => 'ta_business_primary_menu_fallback'
        				) );
        			?>
                    
        		</nav><!-- #site-navigation -->
                
                <?php if( is_active_sidebar( 'ta-business-header-cart-list' ) ){ ?>
                    <div class="tab-cart-header">
                        <i class="fa fa-cart-arrow-down" aria-hidden="true"></i>
                        
                            <?php dynamic_sidebar('ta-business-header-cart-list'); ?>
                            
                    </div>
                <?php } ?>
                
                <div class="tab-search-header">
                    <i class="fa fa-search" aria-hidden="true"></i>
                    <div style="display: none;" class="tab-search-form-header">
                        <?php get_search_form(); ?>
                    </div>
                    
                </div>
                    
            </div>
        </div>
	</header><!-- #masthead -->
    
    <?php if( is_front_page() && !is_home() ){

        $ta_business_news_slide_enable_disable = get_theme_mod('ta_business_news_slide_enable_disable','disable');
        
        
        if( $ta_business_news_slide_enable_disable == 'enable' ){ ?>
            <div class="main-slider-wrap">

                <?php do_action('ta_business_home_slider_callback'); ?>
                
            </div>
        <?php }

    }
    
    if(!is_front_page() || !is_home()){
       do_action('ta_business_header_banner');
    } ?>
    
	<div id="content" class="site-content">