<?php
/**
 * TA Business Theme Customizer
 *
 * @package TA_Business
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function ta_business_customize_register( $wp_customize ) {
    
    $ta_business_Category_list = ta_business_Category_list();
    $ta_business_Posts_List = ta_business_Posts_List();
    $ta_business_Page_list = ta_business_Page_list();
    $ta_business_month = ta_business_month();
    $ta_business_day = ta_business_day();
    $ta_business_year = ta_business_year();
    $ta_business_time = ta_business_time();
    
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';
    $wp_customize->get_section( 'background_image' )->panel = 'ta_business_general_panel';
    $wp_customize->get_section( 'title_tagline' )->panel = 'ta_business_general_panel';
    $wp_customize->get_section( 'header_image' )->panel = 'ta_business_general_panel';  
    $wp_customize->get_section( 'colors' )->panel = 'ta_business_general_panel';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'blogname', array(
			'selector'        => '.site-title a',
			'render_callback' => 'ta_business_customize_partial_blogname',
		) );
		$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
			'selector'        => '.site-description',
			'render_callback' => 'ta_business_customize_partial_blogdescription',
		) );
	}
    
    /** Header Pannel */
	$wp_customize->add_panel(
        'ta_business_header_panel', 
    	array(
    		'priority'       => 5,
        	'capability'     => 'edit_theme_options',
        	'theme_supports' => '',
        	'title'          => esc_html__( 'Header Settings', 'ta-business' ),
        ) 
    );
    /** Banner Section **/
    $wp_customize->add_section(
        'ta_business_top_header_section',
        array(
            'title'		=> esc_html__( 'Top Header Settings', 'ta-business' ),
            'panel'     => 'ta_business_header_panel',
            'priority'  => 15,
        )
    );
    $wp_customize->add_setting(
        'ta_business_news_top_header_info_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_news_top_header_info_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable Top Header Info', 'ta-business' ),
            'section' 	=> 'ta_business_top_header_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_top_header_phone',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_top_header_phone',
        array(
            'label' => esc_html__('Phone Number','ta-business'),
            'priority' => 4,
            'type' => 'text',
            'section' => 'ta_business_top_header_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_top_header_email',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_top_header_email',
        array(
            'label' => esc_html__('Email Address','ta-business'),
            'priority' => 5,
            'type' => 'text',
            'section' => 'ta_business_top_header_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_top_header_location',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_top_header_location',
        array(
            'label' => esc_html__('Address','ta-business'),
            'priority' => 6,
            'type' => 'text',
            'section' => 'ta_business_top_header_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_top_header_social_icon',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_top_header_social_icon', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Top Header Social Icon', 'ta-business' ),
                'section' 	=> 'ta_business_top_header_section',
                'priority'  => 8,
            )	            	
        )
    );
    $wp_customize->add_setting(
        'ta_business_news_top_header_social_icon_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_news_top_header_social_icon_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable Top Header Social Icon', 'ta-business' ),
            'section' 	=> 'ta_business_top_header_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 9,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_top_header_facebook_link',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_top_header_facebook_link',
        array(
            'label' => esc_html__('Facebook Link','ta-business'),
            'priority' => 11,
            'type' => 'text',
            'section' => 'ta_business_top_header_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_top_header_twitter_link',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_top_header_twitter_link',
        array(
            'label' => esc_html__('Twitter Link','ta-business'),
            'priority' => 12,
            'type' => 'text',
            'section' => 'ta_business_top_header_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_top_header_vk_link',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_top_header_vk_link',
        array(
            'label' => esc_html__('VK Link','ta-business'),
            'priority' => 14,
            'type' => 'text',
            'section' => 'ta_business_top_header_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_top_header_youtube_link',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_top_header_youtube_link',
        array(
            'label' => esc_html__('Youtube Link','ta-business'),
            'priority' => 15,
            'type' => 'text',
            'section' => 'ta_business_top_header_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_top_header_google_link',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_top_header_google_link',
        array(
            'label' => esc_html__('Google Link','ta-business'),
            'priority' => 16,
            'type' => 'text',
            'section' => 'ta_business_top_header_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_top_header_instagram_link',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_top_header_instagram_link',
        array(
            'label' => esc_html__('Instagram Link','ta-business'),
            'priority' => 17,
            'type' => 'text',
            'section' => 'ta_business_top_header_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_top_header_linkedin_link',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_top_header_linkedin_link',
        array(
            'label' => esc_html__('Linkedin Link','ta-business'),
            'priority' => 19,
            'type' => 'text',
            'section' => 'ta_business_top_header_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_top_header_pinterest_link',
        array(
            'default' => '',
            'sanitize_callback' => 'esc_url_raw',
        )
    );
    $wp_customize->add_control(
        'ta_business_top_header_pinterest_link',
        array(
            'label' => esc_html__('Pinterest Link','ta-business'),
            'priority' => 20,
            'type' => 'text',
            'section' => 'ta_business_top_header_section'
        )
    );
    
    /** Main Header Layout Section **/
    $wp_customize->add_section(
        'ta_business_main_header_setting',
        array(
            'title'     => esc_html__( 'Main Header Setting', 'ta-business' ),
            'panel'     => 'ta_business_header_panel',
            'priority'  => 100,
        )
    );

    $wp_customize->add_setting(
        'ta_business_main_header_layout',
        array(
            'default' => 'layout-1',
            'sanitize_callback' => 'ta_business_sanitize_radio_image'
        )
    );
    $wp_customize->add_control(
        new TA_Business_Custom_Radio_Image_Control( 
            $wp_customize,
            'ta_business_main_header_layout',
            array(
                'settings'      => 'ta_business_main_header_layout',
                'section'       => 'ta_business_main_header_setting',
                'label'         => esc_html__( 'Main Header Layout', 'ta-business' ),
                'priority'  => 1,
                'choices'       => array(
                    'layout-1'  => get_template_directory_uri() . '/images/Layout-1.png',
                    'layout-2'  => get_template_directory_uri() . '/images/Layout-2.png',
                )
            )
        )
    );

    /** General Pannel */
	$wp_customize->add_panel(
        'ta_business_general_panel', 
    	array(
    		'priority'       => 4,
        	'capability'     => 'edit_theme_options',
        	'theme_supports' => '',
        	'title'          => esc_html__( 'General Settings', 'ta-business' ),
        ) 
    );
    /** Home Pannel */
	$wp_customize->add_panel(
        'ta_business_home_panel', 
    	array(
    		'priority'       => 5,
        	'capability'     => 'edit_theme_options',
        	'theme_supports' => '',
        	'title'          => esc_html__( 'Front Page Settings', 'ta-business' ),
        ) 
    );

    /** Layout Pannel */
    $wp_customize->add_panel(
        'ta_business_layout_pannel', 
        array(
            'priority'       => 5,
            'capability'     => 'edit_theme_options',
            'theme_supports' => '',
            'title'          => esc_html__( 'Layout Settings', 'ta-business' ),
        ) 
    );

    /** Web Layout Section **/
    $wp_customize->add_section(
        'ta_business_web_layout',
        array(
            'title'     => esc_html__( 'Web Layout', 'ta-business' ),
            'panel'     => 'ta_business_layout_pannel',
            'priority'  => 100,
        )
    );

     $wp_customize->add_setting(
        'ta_business_boxed_layout_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_boxed_layout_enable_disable', 
        array(
            'type'      => 'switch',
            'label'     => esc_html__( 'Enable / Disable Boxed Layout', 'ta-business' ),
            'section'   => 'ta_business_web_layout',
            'choices'   => array(
                'enable'    => esc_html__( 'Enable', 'ta-business' ),
                'disable'   => esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );


    /** Section Layout Section **/
    $wp_customize->add_section(
        'ta_business_sections_title_setting',
        array(
            'title'     => esc_html__( 'Section Litle Layout', 'ta-business' ),
            'panel'     => 'ta_business_layout_pannel',
            'priority'  => 100,
        )
    );

    $wp_customize->add_setting(
        'ta_business_sections_title_layout',
        array(
            'default' => 'right_sidebar',
            'sanitize_callback' => 'ta_business_sanitize_radio_image'
        )
    );
    $wp_customize->add_control(
        new TA_Business_Custom_Radio_Image_Control( 
            $wp_customize,
            'ta_business_sections_title_layout',
            array(
                'settings'      => 'ta_business_sections_title_layout',
                'section'       => 'ta_business_sections_title_setting',
                'label'         => esc_html__( 'Section Title Layout', 'ta-business' ),
                'priority'  => 1,
                'choices'       => array(
                    'layout-1'  => get_template_directory_uri() . '/images/Layout-1.png',
                    'layout-2'  => get_template_directory_uri() . '/images/Layout-2.png',
                )
            )
        )
    );

    $wp_customize->add_setting(
        'ta_business_sections_title_icon',
            array(
                'default' => 'fa-heartbeat',
                'sanitize_callback' => 'sanitize_text_field',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_FA_Icons_Control(
        $wp_customize, 
            'ta_business_sections_title_icon', 
            array(
                'type'      => 'ta_business_fa_icons',
                'label'     => esc_html__( 'Title Icon', 'ta-business' ),
                'section'   => 'ta_business_sections_title_setting',
                'priority'  => 7,
                'active_callback' => 'ta_business_section_icon'
            )                   
        )
    );

    /** Web Layout Section **/
    $wp_customize->add_section(
        'ta_business_archive_sidebar',
        array(
            'title'     => esc_html__( 'Archive Sidebar Layout', 'ta-business' ),
            'panel'     => 'ta_business_layout_pannel',
            'priority'  => 100,
        )
    );

    $wp_customize->add_setting(
        'ta_business_archive_sidebar_layout',
        array(
            'default' => 'right_sidebar',
            'sanitize_callback' => 'ta_business_sanitize_sidebar_option'
        )
    );
    $wp_customize->add_control(
        new TA_Business_Custom_Radio_Image_Control( 
            $wp_customize,
            'ta_business_archive_sidebar_layout',
            array(
                'settings'      => 'ta_business_archive_sidebar_layout',
                'section'       => 'ta_business_archive_sidebar',
                'label'         => esc_html__( 'Sidebar Layout', 'ta-business' ),
                'priority'  => 1,
                'choices'       => array(
                    'right_sidebar'  => get_template_directory_uri() . '/images/right-sidebar.png',
                    'left_sidebar'  => get_template_directory_uri() . '/images/left-sidebar.png',
                    'both_sidebar'  => get_template_directory_uri() . '/images/both-sidebar.png',
                    'no_sidebar'  =>  get_template_directory_uri() . '/images/no-sidebar.png',
                )
            )
        )
    );

    /** Single Posts Section **/
    $wp_customize->add_section(
        'ta_business_posts_section',
        array(
            'title'     => esc_html__( 'Post Settings', 'ta-business' ),
            'panel'     => 'ta_business_general_panel',
            'priority'  => 100,
        )
    );

     $wp_customize->add_setting(
        'ta_business_image_enable_disable',
        array(
            'default' => 'enable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_image_enable_disable', 
        array(
            'type'      => 'switch',
            'label'     => esc_html__( 'Enable / Disable Feature Image', 'ta-business' ),
            'section'   => 'ta_business_posts_section',
            'choices'   => array(
                'enable'    => esc_html__( 'Enable', 'ta-business' ),
                'disable'   => esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );

    $wp_customize->add_setting(
        'ta_business_date_enable_disable',
        array(
            'default' => 'enable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_date_enable_disable', 
        array(
            'type'      => 'switch',
            'label'     => esc_html__( 'Enable / Disable Date', 'ta-business' ),
            'section'   => 'ta_business_posts_section',
            'choices'   => array(
                'enable'    => esc_html__( 'Enable', 'ta-business' ),
                'disable'   => esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );

    $wp_customize->add_setting(
        'ta_business_author_enable_disable',
        array(
            'default' => 'enable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_author_enable_disable', 
        array(
            'type'      => 'switch',
            'label'     => esc_html__( 'Enable / Disable Author', 'ta-business' ),
            'section'   => 'ta_business_posts_section',
            'choices'   => array(
                'enable'    => esc_html__( 'Enable', 'ta-business' ),
                'disable'   => esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );

    $wp_customize->add_setting(
        'ta_business_comment_count_enable_disable',
        array(
            'default' => 'enable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_comment_count_enable_disable', 
        array(
            'type'      => 'switch',
            'label'     => esc_html__( 'Enable / Disable Comment Count', 'ta-business' ),
            'section'   => 'ta_business_posts_section',
            'choices'   => array(
                'enable'    => esc_html__( 'Enable', 'ta-business' ),
                'disable'   => esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );

    $wp_customize->add_setting(
        'ta_business_nav_enable_disable',
        array(
            'default' => 'enable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_nav_enable_disable', 
        array(
            'type'      => 'switch',
            'label'     => esc_html__( 'Enable / Disable Navigation', 'ta-business' ),
            'section'   => 'ta_business_posts_section',
            'choices'   => array(
                'enable'    => esc_html__( 'Enable', 'ta-business' ),
                'disable'   => esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );

    /** Archive Posts Section **/
    $wp_customize->add_section(
        'ta_business_post_archive_section',
        array(
            'title'     => esc_html__( 'Archive Settings', 'ta-business' ),
            'panel'     => 'ta_business_general_panel',
            'priority'  => 100,
        )
    );

     $wp_customize->add_setting(
        'ta_business_archive_image_enable_disable',
        array(
            'default' => 'enable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_archive_image_enable_disable', 
        array(
            'type'      => 'switch',
            'label'     => esc_html__( 'Enable / Disable Feature Image', 'ta-business' ),
            'section'   => 'ta_business_post_archive_section',
            'choices'   => array(
                'enable'    => esc_html__( 'Enable', 'ta-business' ),
                'disable'   => esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );

    $wp_customize->add_setting(
        'ta_business_archive_date_enable_disable',
        array(
            'default' => 'enable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_archive_date_enable_disable', 
        array(
            'type'      => 'switch',
            'label'     => esc_html__( 'Enable / Disable Date', 'ta-business' ),
            'section'   => 'ta_business_post_archive_section',
            'choices'   => array(
                'enable'    => esc_html__( 'Enable', 'ta-business' ),
                'disable'   => esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );

    $wp_customize->add_setting(
        'ta_business_archive_author_enable_disable',
        array(
            'default' => 'enable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_archive_author_enable_disable', 
        array(
            'type'      => 'switch',
            'label'     => esc_html__( 'Enable / Disable Author', 'ta-business' ),
            'section'   => 'ta_business_post_archive_section',
            'choices'   => array(
                'enable'    => esc_html__( 'Enable', 'ta-business' ),
                'disable'   => esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );

    $wp_customize->add_setting(
        'ta_business_archive_comment_count_enable_disable',
        array(
            'default' => 'enable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_archive_comment_count_enable_disable', 
        array(
            'type'      => 'switch',
            'label'     => esc_html__( 'Enable / Disable Comment Count', 'ta-business' ),
            'section'   => 'ta_business_post_archive_section',
            'choices'   => array(
                'enable'    => esc_html__( 'Enable', 'ta-business' ),
                'disable'   => esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );

    $wp_customize->add_setting(
        'ta_business_archive_pagination_enable_disable',
        array(
            'default' => 'enable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_archive_pagination_enable_disable', 
        array(
            'type'      => 'switch',
            'label'     => esc_html__( 'Enable / Disable Pagination', 'ta-business' ),
            'section'   => 'ta_business_post_archive_section',
            'choices'   => array(
                'enable'    => esc_html__( 'Enable', 'ta-business' ),
                'disable'   => esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );

    $wp_customize->add_setting(
        'ta_business_archive_button_lebel',
        array(
            'default' => esc_html__('Read More','ta-business'),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_archive_button_lebel',
        array(
            'label' => esc_html__('Read More Button Label','ta-business'),
            'priority' => 1,
            'type' => 'text',
            'section' => 'ta_business_post_archive_section',
            'active_callback' => 'ta_business_about_skill',
        )
    );

    /** Home Setting **/
    $wp_customize->add_section(
        'ta_business_home_settings',
        array(
            'title'     => esc_html__( 'Home Sections Settings', 'ta-business' ),
            'panel'     => 'ta_business_general_panel',
            'priority'  => 100,
        )
    );

    $wp_customize->add_setting(
        'ta_business_read_more_text',
        array(
            'default' => esc_html__( 'Read More', 'ta-business' ),
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_read_more_text',
        array(
            'label' => esc_html__('Read More Text','ta-business'),
            'priority' => 1,
            'type' => 'text',
            'section' => 'ta_business_home_settings',
        )
    );

    /** Banner Section **/
    $wp_customize->add_section(
        'ta_business_home_banner_section',
        array(
            'title'		=> esc_html__( 'Slide Banner Settings', 'ta-business' ),
            'panel'     => 'ta_business_home_panel',
            'priority'  => 15,
        )
    );
    $wp_customize->add_setting(
        'ta_business_news_slide_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_news_slide_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable Banner', 'ta-business' ),
            'description' 	=> esc_html__( 'Home Page Header Banner', 'ta-business' ),
            'section' 	=> 'ta_business_home_banner_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slide_cat',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_cat_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_slide_cat',
        array(
            'label' => esc_html__('Slide Category','ta-business'),
            'priority' => 2,
            'type' => 'select',
            'choices' => $ta_business_Category_list,
            'section' => 'ta_business_home_banner_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slider_feature_post_layout',
        array(
            'default' => 'layout-1',
            'sanitize_callback' => 'ta_business_sanitize_radio_image'
        )
    );
   	$wp_customize->add_control(
		new TA_Business_Custom_Radio_Image_Control( 
			$wp_customize,
			'ta_business_slider_feature_post_layout',
			array(
				'settings'		=> 'ta_business_slider_feature_post_layout',
				'section'		=> 'ta_business_home_banner_section',
				'label'			=> esc_html__( 'Banner Feature Post Layout', 'ta-business' ),
                'priority'  => 4,
				'choices'		=> array(
					'layout-1' 	=> get_template_directory_uri() . '/images/Layout-1.png',
					'layout-2' 	=> get_template_directory_uri() . '/images/Layout-2.png',
				)
			)
		)
	);
    
    $wp_customize->add_setting(
        'ta_business_slider_feature_post_one',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_slider_feature_post_one', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Banner Feature Post One', 'ta-business' ),
                'section' 	=> 'ta_business_home_banner_section',
                'priority'  => 5,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slider_feature_post_icon_one',
	        array(
	            'default' => 'fa-bookmark-o',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_FA_Icons_Control(
        $wp_customize, 
            'ta_business_slider_feature_post_icon_one', 
            array(
                'type' 		=> 'ta_business_fa_icons',
                'label' 	=> esc_html__( 'Feature FA Iocn One', 'ta-business' ),
                'section' 	=> 'ta_business_home_banner_section',
                'priority'  => 7,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slide_feature_post_one',
        array(
            'default' => '',
            'sanitize_callback' => 'ta_business_sanitize_post_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_slide_feature_post_one',
        array(
            'label' => esc_html__('Banner Feature Post One','ta-business'),
            'priority' => 8,
            'type' => 'select',
            'choices' => $ta_business_Posts_List,
            'section' => 'ta_business_home_banner_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slide_feature_post_color_one',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_hex_color',
        )
    );
    $wp_customize->add_control(
	   new WP_Customize_Color_Control(
        	$wp_customize, 
        	'ta_business_slide_feature_post_color_one', 
        	array(
        		'label'      => esc_html__( 'Feature Post Color One', 'ta-business' ),
        		'section'    => 'ta_business_home_banner_section',
        		'settings'   => 'ta_business_slide_feature_post_color_one',
                'priority' => 9,
        	)
        )
   );
   
   $wp_customize->add_setting(
        'ta_business_slider_feature_post_two',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_slider_feature_post_two', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Banner Feature Post Two', 'ta-business' ),
                'section' 	=> 'ta_business_home_banner_section',
                'priority'  => 15,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slider_feature_post_icon_two',
	        array(
	            'default' => 'fa-bookmark-o',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_FA_Icons_Control(
        $wp_customize, 
            'ta_business_slider_feature_post_icon_two', 
            array(
                'type' 		=> 'ta_business_fa_icons',
                'label' 	=> esc_html__( 'Feature FA Iocn Two', 'ta-business' ),
                'section' 	=> 'ta_business_home_banner_section',
                'priority'  => 17,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slide_feature_post_two',
        array(
            'default' => '',
            'sanitize_callback' => 'ta_business_sanitize_post_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_slide_feature_post_two',
        array(
            'label' => esc_html__('Banner Feature Post Two','ta-business'),
            'priority' => 18,
            'type' => 'select',
            'choices' => $ta_business_Posts_List,
            'section' => 'ta_business_home_banner_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slide_feature_post_color_two',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_hex_color',
        )
    );
    $wp_customize->add_control(
	   new WP_Customize_Color_Control(
        	$wp_customize, 
        	'ta_business_slide_feature_post_color_two', 
        	array(
        		'label'      => esc_html__( 'Feature Post Color Two', 'ta-business' ),
        		'section'    => 'ta_business_home_banner_section',
        		'settings'   => 'ta_business_slide_feature_post_color_two',
                'priority' => 20,
        	)
        )
   );
   
   $wp_customize->add_setting(
        'ta_business_slider_feature_post_three',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_slider_feature_post_three', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Banner Feature Post Three', 'ta-business' ),
                'section' 	=> 'ta_business_home_banner_section',
                'priority'  => 25,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slider_feature_post_icon_three',
	        array(
	            'default' => 'fa-bookmark-o',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_FA_Icons_Control(
        $wp_customize, 
            'ta_business_slider_feature_post_icon_three', 
            array(
                'type' 		=> 'ta_business_fa_icons',
                'label' 	=> esc_html__( 'Feature FA Iocn Three', 'ta-business' ),
                'section' 	=> 'ta_business_home_banner_section',
                'priority'  => 27,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slide_feature_post_three',
        array(
            'default' => '',
            'sanitize_callback' => 'ta_business_sanitize_post_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_slide_feature_post_three',
        array(
            'label' => esc_html__('Banner Feature Post Three','ta-business'),
            'priority' => 28,
            'type' => 'select',
            'choices' => $ta_business_Posts_List,
            'section' => 'ta_business_home_banner_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slide_feature_post_color_three',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_hex_color',
        )
    );
    $wp_customize->add_control(
	   new WP_Customize_Color_Control(
        	$wp_customize, 
        	'ta_business_slide_feature_post_color_three', 
        	array(
        		'label'      => esc_html__( 'Feature Post Color Three', 'ta-business' ),
        		'section'    => 'ta_business_home_banner_section',
        		'settings'   => 'ta_business_slide_feature_post_color_three',
                'priority' => 29,
        	)
        )
   );
   
   $wp_customize->add_setting(
        'ta_business_slider_feature_post_four',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_slider_feature_post_four', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Banner Feature Post Four', 'ta-business' ),
                'section' 	=> 'ta_business_home_banner_section',
                'priority'  => 35,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slider_feature_post_icon_four',
	        array(
	            'default' => 'fa-bookmark-o',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_FA_Icons_Control(
        $wp_customize, 
            'ta_business_slider_feature_post_icon_four', 
            array(
                'type' 		=> 'ta_business_fa_icons',
                'label' 	=> esc_html__( 'Feature FA Iocn Four', 'ta-business' ),
                'section' 	=> 'ta_business_home_banner_section',
                'priority'  => 37,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slide_feature_post_four',
        array(
            'default' => '',
            'sanitize_callback' => 'ta_business_sanitize_post_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_slide_feature_post_four',
        array(
            'label' => esc_html__('Slide Feature Post Four','ta-business'),
            'priority' => 38,
            'type' => 'select',
            'choices' => $ta_business_Posts_List,
            'section' => 'ta_business_home_banner_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_slide_feature_post_color_four',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_hex_color',
        )
    );
    $wp_customize->add_control(
	   new WP_Customize_Color_Control(
        	$wp_customize, 
        	'ta_business_slide_feature_post_color_four', 
        	array(
        		'label'      => esc_html__( 'Feature Post Color Four', 'ta-business' ),
        		'section'    => 'ta_business_home_banner_section',
        		'settings'   => 'ta_business_slide_feature_post_color_four',
                'priority' => 39,
        	)
        )
   );

    /** About Section **/
    $wp_customize->add_section(
        'ta_business_home_about_section',
        array(
            'title'		=> esc_html__( 'About Section', 'ta-business' ),
            'panel'     => 'ta_business_home_panel',
            'priority'  => 19,
        )
    );
    $wp_customize->add_setting(
        'ta_business_about_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_about_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable About Section', 'ta-business' ),
            'section' 	=> 'ta_business_home_about_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_about_post',
        array(
            'default' => '',
            'sanitize_callback' => 'ta_business_sanitize_post_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_about_post',
        array(
            'label' => esc_html__('About Post','ta-business'),
            'priority' => 2,
            'type' => 'select',
            'choices' => $ta_business_Posts_List,
            'section' => 'ta_business_home_about_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_about_layout',
        array(
            'default' => 'layout-1',
            'sanitize_callback' => 'ta_business_sanitize_radio_image'
        )
    );
   	$wp_customize->add_control(
		new TA_Business_Custom_Radio_Image_Control( 
			$wp_customize,
			'ta_business_about_layout',
			array(
				'settings'		=> 'ta_business_about_layout',
				'section'		=> 'ta_business_home_about_section',
				'label'			=> esc_html__( 'About Section Layout', 'ta-business' ),
                'priority'  => 5,
				'choices'		=> array(
					'layout-1' 	=> get_template_directory_uri() . '/images/Layout-1.png',
					'layout-2' 	=> get_template_directory_uri() . '/images/Layout-2.png',
				)
			)
		)
	);
    
    $wp_customize->add_setting(
        'ta_business_about_image_sep',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_about_image_sep', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'About Right Image', 'ta-business' ),
                'section' 	=> 'ta_business_home_about_section',
                'priority'  => 6,
                'active_callback' => 'ta_business_about_image',
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_about_section_image',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'esc_url_raw'
	        )
    );
    $wp_customize->add_control( new WP_Customize_Image_Control(
        $wp_customize,
        'ta_business_about_section_image',
        	array(
            	'label'      => esc_html__( 'About Section Image', 'ta-business' ),
               	'section'    => 'ta_business_home_about_section',
               	'priority' => 6,
                'active_callback' => 'ta_business_about_image',
           	)
       	)
   	);
    
    $wp_customize->add_setting(
        'ta_business_about_skill_sep',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_about_skill_sep', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'About Section Skill', 'ta-business' ),
                'section' 	=> 'ta_business_home_about_section',
                'priority'  => 8,
                'active_callback' => 'ta_business_about_skill',
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_about_skill_1_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_about_skill_1_title',
        array(
            'label' => esc_html__('Skill Title One','ta-business'),
            'priority' => 15,
            'type' => 'text',
            'section' => 'ta_business_home_about_section',
            'active_callback' => 'ta_business_about_skill',
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_about_skill_1_percent',
        array(
            'default' => '',
            'sanitize_callback' => 'absint',
        )
    );
    $wp_customize->add_control(
        'ta_business_about_skill_1_percent',
        array(
            'label' => esc_html__('Skill Percentage One','ta-business'),
            'priority' => 16,
            'type' => 'number',
            'section' => 'ta_business_home_about_section',
            'active_callback' => 'ta_business_about_skill',
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_about_skill_2_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_about_skill_2_title',
        array(
            'label' => esc_html__('Skill Title Two','ta-business'),
            'priority' => 20,
            'type' => 'text',
            'section' => 'ta_business_home_about_section',
            'active_callback' => 'ta_business_about_skill',
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_about_skill_2_percent',
        array(
            'default' => '',
            'sanitize_callback' => 'absint',
        )
    );
    $wp_customize->add_control(
        'ta_business_about_skill_2_percent',
        array(
            'label' => esc_html__('Skill Percentage Two','ta-business'),
            'priority' => 21,
            'type' => 'number',
            'section' => 'ta_business_home_about_section',
            'active_callback' => 'ta_business_about_skill',
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_about_skill_3_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_about_skill_3_title',
        array(
            'label' => esc_html__('Skill Title Three','ta-business'),
            'priority' => 25,
            'type' => 'text',
            'section' => 'ta_business_home_about_section',
            'active_callback' => 'ta_business_about_skill',
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_about_skill_3_percent',
        array(
            'default' => '',
            'sanitize_callback' => 'absint',
        )
    );
    $wp_customize->add_control(
        'ta_business_about_skill_3_percent',
        array(
            'label' => esc_html__('Skill Percentage Three','ta-business'),
            'priority' => 26,
            'type' => 'number',
            'section' => 'ta_business_home_about_section',
            'active_callback' => 'ta_business_about_skill',
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_about_skill_4_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_about_skill_4_title',
        array(
            'label' => esc_html__('Skill Title Four','ta-business'),
            'priority' => 30,
            'type' => 'text',
            'section' => 'ta_business_home_about_section',
            'active_callback' => 'ta_business_about_skill',
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_about_skill_4_percent',
        array(
            'default' => '',
            'sanitize_callback' => 'absint',
        )
    );
    $wp_customize->add_control(
        'ta_business_about_skill_4_percent',
        array(
            'label' => esc_html__('Skill Percentage Furo','ta-business'),
            'priority' => 31,
            'type' => 'number',
            'section' => 'ta_business_home_about_section',
            'active_callback' => 'ta_business_about_skill',
        )
    );
    
    
    /** Blog Section **/
    $wp_customize->add_section(
        'ta_business_home_blog_section',
        array(
            'title'		=> esc_html__( 'Blog Section', 'ta-business' ),
            'panel'     => 'ta_business_home_panel',
            'priority'  => 20,
        )
    );
    $wp_customize->add_setting(
        'ta_business_blog_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_blog_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable Blog Section', 'ta-business' ),
            'section' 	=> 'ta_business_home_blog_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_blog_section_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_blog_section_title',
        array(
            'label' => esc_html__('Section Title','ta-business'),
            'priority' => 4,
            'type' => 'text',
            'section' => 'ta_business_home_blog_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_blog_cat',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_cat_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_blog_cat',
        array(
            'label' => esc_html__('Blog Category','ta-business'),
            'priority' => 7,
            'type' => 'select',
            'choices' => $ta_business_Category_list,
            'section' => 'ta_business_home_blog_section'
        )
    );
    
    /** Portfolio Section **/
    $wp_customize->add_section(
        'ta_business_home_portfolio_section',
        array(
            'title'		=> esc_html__( 'Portfolio Section', 'ta-business' ),
            'panel'     => 'ta_business_home_panel',
            'priority'  => 20,
        )
    );
    $wp_customize->add_setting(
        'ta_business_portfolio_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_portfolio_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable Portfolio Section', 'ta-business' ),
            'section' 	=> 'ta_business_home_portfolio_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_portfolio_section_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_portfolio_section_title',
        array(
            'label' => esc_html__('Section Title','ta-business'),
            'priority' => 4,
            'type' => 'text',
            'section' => 'ta_business_home_portfolio_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_portfolio_layout',
        array(
            'default' => 'layout-1',
            'sanitize_callback' => 'ta_business_sanitize_radio_image'
        )
    );
   	$wp_customize->add_control(
		new TA_Business_Custom_Radio_Image_Control( 
			$wp_customize,
			'ta_business_portfolio_layout',
			array(
				'settings'		=> 'ta_business_portfolio_layout',
				'section'		=> 'ta_business_home_portfolio_section',
				'label'			=> esc_html__( 'Portfolio Section Layout', 'ta-business' ),
                'priority'  => 5,
				'choices'		=> array(
					'layout-1' 	=> get_template_directory_uri() . '/images/Layout-1.png',
					'layout-2' 	=> get_template_directory_uri() . '/images/Layout-2.png',
				)
			)
		)
	);
    
    $wp_customize->add_setting(
        'ta_business_portfolio_cat',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_cat_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_portfolio_cat',
        array(
            'label' => esc_html__('Portfolio Category','ta-business'),
            'priority' => 7,
            'type' => 'select',
            'choices' => $ta_business_Category_list,
            'section' => 'ta_business_home_portfolio_section'
        )
    );
    
    /** Counter Section **/
    $wp_customize->add_section(
        'ta_business_home_counter_section',
        array(
            'title'		=> esc_html__( 'Counter Section', 'ta-business' ),
            'panel'     => 'ta_business_home_panel',
            'priority'  => 20,
        )
    );
    $wp_customize->add_setting(
        'ta_business_counter_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_counter_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable Counter Section', 'ta-business' ),
            'section' 	=> 'ta_business_home_counter_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_layout',
        array(
            'default' => 'layout-1',
            'sanitize_callback' => 'ta_business_sanitize_radio_image'
        )
    );
   	$wp_customize->add_control(
		new TA_Business_Custom_Radio_Image_Control( 
			$wp_customize,
			'ta_business_counter_layout',
			array(
				'settings'		=> 'ta_business_counter_layout',
				'section'		=> 'ta_business_home_counter_section',
				'label'			=> esc_html__( 'Counter Section Layout', 'ta-business' ),
                'priority'  => 5,
				'choices'		=> array(
					'layout-1' 	=> get_template_directory_uri() . '/images/Layout-1.png',
					'layout-2' 	=> get_template_directory_uri() . '/images/Layout-2.png',
				)
			)
		)
	);
    
    $wp_customize->add_setting(
        'ta_business_counter_section_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_counter_section_title',
        array(
            'label' => esc_html__('Section Title','ta-business'),
            'priority' => 6,
            'type' => 'text',
            'section' => 'ta_business_home_counter_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_sep_one',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_counter_sep_one', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Counter One', 'ta-business' ),
                'section' 	=> 'ta_business_home_counter_section',
                'priority'  => 7,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_icon_one',
	        array(
	            'default' => 'fa-bookmark-o',
	            'sanitize_callback' => 'sanitize_text_field',
                'transport' => 'postMessage',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_FA_Icons_Control(
        $wp_customize, 
            'ta_business_counter_icon_one', 
            array(
                'type' 		=> 'ta_business_fa_icons',
                'label' 	=> esc_html__( 'Counter Iocn One', 'ta-business' ),
                'section' 	=> 'ta_business_home_counter_section',
                'priority'  => 8,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_title_one',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_counter_title_one',
        array(
            'label' => esc_html__('Counter Title One','ta-business'),
            'priority' => 10,
            'type' => 'text',
            'section' => 'ta_business_home_counter_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_count_one',
        array(
            'default' => '',
            'sanitize_callback' => 'absint',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_counter_count_one',
        array(
            'label' => esc_html__('Counter Count One','ta-business'),
            'priority' => 11,
            'type' => 'text',
            'section' => 'ta_business_home_counter_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_sep_two',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_counter_sep_two', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Counter Two', 'ta-business' ),
                'section' 	=> 'ta_business_home_counter_section',
                'priority'  => 15,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_icon_two',
	        array(
	            'default' => 'fa-bookmark-o',
	            'sanitize_callback' => 'sanitize_text_field',
                'transport' => 'postMessage',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_FA_Icons_Control(
        $wp_customize, 
            'ta_business_counter_icon_two', 
            array(
                'type' 		=> 'ta_business_fa_icons',
                'label' 	=> esc_html__( 'Counter Iocn Two', 'ta-business' ),
                'section' 	=> 'ta_business_home_counter_section',
                'priority'  => 16,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_title_two',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_counter_title_two',
        array(
            'label' => esc_html__('Counter Title Two','ta-business'),
            'priority' => 17,
            'type' => 'text',
            'section' => 'ta_business_home_counter_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_count_two',
        array(
            'default' => '',
            'sanitize_callback' => 'absint',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_counter_count_two',
        array(
            'label' => esc_html__('Counter Count Two','ta-business'),
            'priority' => 18,
            'type' => 'text',
            'section' => 'ta_business_home_counter_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_sep_three',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_counter_sep_three', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Counter Three', 'ta-business' ),
                'section' 	=> 'ta_business_home_counter_section',
                'priority'  => 20,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_icon_three',
	        array(
	            'default' => 'fa-bookmark-o',
	            'sanitize_callback' => 'sanitize_text_field',
                'transport' => 'postMessage',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_FA_Icons_Control(
        $wp_customize, 
            'ta_business_counter_icon_three', 
            array(
                'type' 		=> 'ta_business_fa_icons',
                'label' 	=> esc_html__( 'Counter Iocn Three', 'ta-business' ),
                'section' 	=> 'ta_business_home_counter_section',
                'priority'  => 21,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_title_three',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_counter_title_three',
        array(
            'label' => esc_html__('Counter Title Three','ta-business'),
            'priority' => 22,
            'type' => 'text',
            'section' => 'ta_business_home_counter_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_count_three',
        array(
            'default' => '',
            'sanitize_callback' => 'absint',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_counter_count_three',
        array(
            'label' => esc_html__('Counter Count Three','ta-business'),
            'priority' => 23,
            'type' => 'text',
            'section' => 'ta_business_home_counter_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_sep_four',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_counter_sep_four', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Counter Four', 'ta-business' ),
                'section' 	=> 'ta_business_home_counter_section',
                'priority'  => 30,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_icon_four',
	        array(
	            'default' => 'fa-bookmark-o',
	            'sanitize_callback' => 'sanitize_text_field',
                'transport' => 'postMessage',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_FA_Icons_Control(
        $wp_customize, 
            'ta_business_counter_icon_four', 
            array(
                'type' 		=> 'ta_business_fa_icons',
                'label' 	=> esc_html__( 'Counter Iocn Four', 'ta-business' ),
                'section' 	=> 'ta_business_home_counter_section',
                'priority'  => 31,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_title_four',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_counter_title_four',
        array(
            'label' => esc_html__('Counter Title Four','ta-business'),
            'priority' => 32,
            'type' => 'text',
            'section' => 'ta_business_home_counter_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_counter_count_four',
        array(
            'default' => '',
            'sanitize_callback' => 'absint',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_counter_count_four',
        array(
            'label' => esc_html__('Counter Count Four','ta-business'),
            'priority' => 33,
            'type' => 'text',
            'section' => 'ta_business_home_counter_section'
        )
    );
    
    /** Service Section **/
    $wp_customize->add_section(
        'ta_business_home_service_section',
        array(
            'title'		=> esc_html__( 'Service Section', 'ta-business' ),
            'panel'     => 'ta_business_home_panel',
            'priority'  => 20,
        )
    );
    $wp_customize->add_setting(
        'ta_business_service_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_service_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable Service Section', 'ta-business' ),
            'section' 	=> 'ta_business_home_service_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_service_section_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_service_section_title',
        array(
            'label' => esc_html__('Section Title','ta-business'),
            'priority' => 4,
            'type' => 'text',
            'section' => 'ta_business_home_service_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_service_layout',
        array(
            'default' => 'layout-1',
            'sanitize_callback' => 'ta_business_sanitize_radio_image'
        )
    );
   	$wp_customize->add_control(
		new TA_Business_Custom_Radio_Image_Control( 
			$wp_customize,
			'ta_business_service_layout',
			array(
				'settings'		=> 'ta_business_service_layout',
				'section'		=> 'ta_business_home_service_section',
				'label'			=> esc_html__( 'Service Section Layout', 'ta-business' ),
                'priority'  => 6,
				'choices'		=> array(
					'layout-1' 	=> get_template_directory_uri() . '/images/Layout-1.png',
					'layout-2' 	=> get_template_directory_uri() . '/images/Layout-2.png',
				),
			)
		)
	);
    
    $wp_customize->add_setting(
        'ta_business_service_mid_img_sep',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_service_mid_img_sep', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Service Section Image', 'ta-business' ),
                'section' 	=> 'ta_business_home_service_section',
                'priority'  => 10,
                'active_callback' => 'ta_business_service_image'
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_service_section_mid_image',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'esc_url_raw'
	        )
    );

    $wp_customize->add_control( new WP_Customize_Image_Control(
        $wp_customize,
        'ta_business_service_section_mid_image',
        	array(
            	'label'      => esc_html__( 'Service Section Image', 'ta-business' ),
               	'section'    => 'ta_business_home_service_section',
               	'priority' => 12,
                'active_callback' => 'ta_business_service_image'
           	)
       	)
   	);
    
    $wp_customize->add_setting(
        'ta_business_service_left_posts',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_service_left_posts', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Service Left Posts', 'ta-business' ),
                'section' 	=> 'ta_business_home_service_section',
                'priority'  => 14,
                'active_callback' => 'ta_business_service_image'
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_service_post_1',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_service_post_1',
        array(
            'label' => esc_html__('Service Post One','ta-business'),
            'priority' => 16,
            'type' => 'select',
            'choices' => $ta_business_Posts_List,
            'section' => 'ta_business_home_service_section'
        )
    );
    $wp_customize->add_setting(
        'ta_business_service_post_2',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_service_post_2',
        array(
            'label' => esc_html__('Service Post Two','ta-business'),
            'priority' => 18,
            'type' => 'select',
            'choices' => $ta_business_Posts_List,
            'section' => 'ta_business_home_service_section'
        )
    );
    $wp_customize->add_setting(
        'ta_business_service_post_3',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_service_post_3',
        array(
            'label' => esc_html__('Service Post Three','ta-business'),
            'priority' => 20,
            'type' => 'select',
            'choices' => $ta_business_Posts_List,
            'section' => 'ta_business_home_service_section'
        )
    );
    $wp_customize->add_setting(
        'ta_business_service_post_4',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_service_post_4',
        array(
            'label' => esc_html__('Service Post Four','ta-business'),
            'priority' => 21,
            'type' => 'select',
            'choices' => $ta_business_Posts_List,
            'section' => 'ta_business_home_service_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_service_right_posts',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_service_right_posts', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Service Right Posts', 'ta-business' ),
                'section' 	=> 'ta_business_home_service_section',
                'priority'  => 22,
                'active_callback' => 'ta_business_service_image'
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_service_post_5',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_service_post_5',
        array(
            'label' => esc_html__('Service Post Five','ta-business'),
            'priority' => 25,
            'type' => 'select',
            'choices' => $ta_business_Posts_List,
            'section' => 'ta_business_home_service_section'
        )
    );
    $wp_customize->add_setting(
        'ta_business_service_post_6',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_service_post_6',
        array(
            'label' => esc_html__('Service Post Six','ta-business'),
            'priority' => 26,
            'type' => 'select',
            'choices' => $ta_business_Posts_List,
            'section' => 'ta_business_home_service_section'
        )
    );
    $wp_customize->add_setting(
        'ta_business_service_post_7',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_service_post_7',
        array(
            'label' => esc_html__('Service Post Seven','ta-business'),
            'priority' => 28,
            'type' => 'select',
            'choices' => $ta_business_Posts_List,
            'section' => 'ta_business_home_service_section'
        )
    );
    $wp_customize->add_setting(
        'ta_business_service_post_8',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_service_post_8',
        array(
            'label' => esc_html__('Service Post Eight','ta-business'),
            'priority' => 30,
            'type' => 'select',
            'choices' => $ta_business_Posts_List,
            'section' => 'ta_business_home_service_section'
        )
    );
    
    /** Team Section **/
    $wp_customize->add_section(
        'ta_business_home_team_section',
        array(
            'title'		=> esc_html__( 'Team Section', 'ta-business' ),
            'panel'     => 'ta_business_home_panel',
            'priority'  => 20,
        )
    );
    $wp_customize->add_setting(
        'ta_business_team_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_team_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable Team Section', 'ta-business' ),
            'section' 	=> 'ta_business_home_team_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_team_section_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_team_section_title',
        array(
            'label' => esc_html__('Section Title','ta-business'),
            'priority' => 4,
            'type' => 'text',
            'section' => 'ta_business_home_team_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_team_layout',
        array(
            'default' => 'layout-1',
            'sanitize_callback' => 'ta_business_sanitize_radio_image'
        )
    );
   	$wp_customize->add_control(
		new TA_Business_Custom_Radio_Image_Control( 
			$wp_customize,
			'ta_business_team_layout',
			array(
				'settings'		=> 'ta_business_team_layout',
				'section'		=> 'ta_business_home_team_section',
				'label'			=> esc_html__( 'Team Section Layout', 'ta-business' ),
                'priority'  => 5,
				'choices'		=> array(
					'layout-1' 	=> get_template_directory_uri() . '/images/Layout-1.png',
					'layout-2' 	=> get_template_directory_uri() . '/images/Layout-2.png',
				)
			)
		)
	);
    
    $wp_customize->add_setting(
        'ta_business_team_cat',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_cat_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_team_cat',
        array(
            'label' => esc_html__('Team Category','ta-business'),
            'priority' => 7,
            'type' => 'select',
            'choices' => $ta_business_Category_list,
            'section' => 'ta_business_home_team_section'
        )
    );
    
    /** Countdown Section **/
    $wp_customize->add_section(
        'ta_business_home_countdown_section',
        array(
            'title'		=> esc_html__( 'Countdown Section', 'ta-business' ),
            'panel'     => 'ta_business_home_panel',
            'priority'  => 20,
        )
    );
    $wp_customize->add_setting(
        'ta_business_countdown_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_countdown_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable countdown Section', 'ta-business' ),
            'section' 	=> 'ta_business_home_countdown_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_countdown_form_section',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_countdown_form_section', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Form Fields', 'ta-business' ),
                'section' 	=> 'ta_business_home_countdown_section',
                'priority'  => 2,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_countdown_form_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_countdown_form_title',
        array(
            'label' => esc_html__('Form Title Title','ta-business'),
            'priority' => 4,
            'type' => 'text',
            'section' => 'ta_business_home_countdown_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_countdown_form',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_page_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_countdown_form',
        array(
            'label' => esc_html__('Form Page','ta-business'),
            'priority' => 6,
            'type' => 'select',
            'choices' => $ta_business_Page_list,
            'section' => 'ta_business_home_countdown_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_countdown_section',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_countdown_section', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Countdown Fields', 'ta-business' ),
                'section' 	=> 'ta_business_home_countdown_section',
                'priority'  => 8,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_countdown_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_countdown_title',
        array(
            'label' => esc_html__('Countdown Title','ta-business'),
            'priority' => 9,
            'type' => 'text',
            'section' => 'ta_business_home_countdown_section'
        )
    );
    $wp_customize->add_setting(
        'ta_business_countdown_desc',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_countdown_desc',
        array(
            'label' => esc_html__('Countdown Section Description','ta-business'),
            'priority' => 10,
            'type' => 'text',
            'section' => 'ta_business_home_countdown_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_countdown_button_link',
        array(
            'default' => '',
            'sanitize_callback' => 'esc_url_raw',
        )
    );
    $wp_customize->add_control(
        'ta_business_countdown_button_link',
        array(
            'label' => esc_html__('Countdown Button Link','ta-business'),
            'priority' => 11,
            'type' => 'text',
            'section' => 'ta_business_home_countdown_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_countdown_month',
        array(
            'default' => '',
            'sanitize_callback' => 'ta_business_sanitize_month_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_countdown_month',
        array(
            'label' => esc_html__('Countdown Month','ta-business'),
            'priority' => 12,
            'type' => 'select',
            'choices' => $ta_business_month,
            'section' => 'ta_business_home_countdown_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_countdown_day',
        array(
            'default' => '',
            'sanitize_callback' => 'ta_business_sanitize_day_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_countdown_day',
        array(
            'label' => esc_html__('Countdown Day','ta-business'),
            'priority' => 14,
            'type' => 'select',
            'choices' => $ta_business_day,
            'section' => 'ta_business_home_countdown_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_countdown_year',
        array(
            'default' => '',
            'sanitize_callback' => 'ta_business_sanitize_year_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_countdown_year',
        array(
            'label' => esc_html__('Countdown Year','ta-business'),
            'priority' => 16,
            'type' => 'select',
            'choices' => $ta_business_year,
            'section' => 'ta_business_home_countdown_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_countdown_time',
        array(
            'default' => '',
            'sanitize_callback' => 'ta_business_sanitize_time_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_countdown_time',
        array(
            'label' => esc_html__('Countdown Time','ta-business'),
            'priority' => 18,
            'type' => 'select',
            'choices' => $ta_business_time,
            'section' => 'ta_business_home_countdown_section'
        )
    );
    
    /** Testimonial Section **/
    $wp_customize->add_section(
        'ta_business_home_testimonial_section',
        array(
            'title'		=> esc_html__( 'Testimonial Section', 'ta-business' ),
            'panel'     => 'ta_business_home_panel',
            'priority'  => 20,
        )
    );
    $wp_customize->add_setting(
        'ta_business_testimonial_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_testimonial_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable Testimonial Section', 'ta-business' ),
            'section' 	=> 'ta_business_home_testimonial_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_testimonial_section_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_testimonial_section_title',
        array(
            'label' => esc_html__('Section Title','ta-business'),
            'priority' => 4,
            'type' => 'text',
            'section' => 'ta_business_home_testimonial_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_testimonial_cat',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_cat_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_testimonial_cat',
        array(
            'label' => esc_html__('Testimonial Category','ta-business'),
            'priority' => 7,
            'type' => 'select',
            'choices' => $ta_business_Category_list,
            'section' => 'ta_business_home_testimonial_section'
        )
    );
    
    /** Subscribe Section **/
    $wp_customize->add_section(
        'ta_business_home_subscribe_section',
        array(
            'title'		=> esc_html__( 'Subscribe Section', 'ta-business' ),
            'panel'     => 'ta_business_home_panel',
            'priority'  => 20,
        )
    );
    $wp_customize->add_setting(
        'ta_business_subscribe_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_subscribe_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable Subscribe Section', 'ta-business' ),
            'section' 	=> 'ta_business_home_subscribe_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_subscribe_section_image',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'esc_url_raw'
	        )
    );
    $wp_customize->add_control( new WP_Customize_Image_Control(
        $wp_customize,
        'ta_business_subscribe_section_image',
        	array(
            	'label'      => esc_html__( 'Background Image', 'ta-business' ),
               	'section'    => 'ta_business_home_subscribe_section',
               	'priority' => 6,
           	)
       	)
   	);
    
    /** Client Section **/
    $wp_customize->add_section(
        'ta_business_home_client_section',
        array(
            'title'		=> esc_html__( 'Client Section', 'ta-business' ),
            'panel'     => 'ta_business_home_panel',
            'priority'  => 20,
        )
    );
    $wp_customize->add_setting(
        'ta_business_client_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_client_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable Client Section', 'ta-business' ),
            'section' 	=> 'ta_business_home_client_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_client_section_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_client_section_title',
        array(
            'label' => esc_html__('Section Title','ta-business'),
            'priority' => 4,
            'type' => 'text',
            'section' => 'ta_business_home_client_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_client_cat',
        array(
            'default' => '0',
            'sanitize_callback' => 'ta_business_sanitize_post_cat_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_client_cat',
        array(
            'label' => esc_html__('Client Category','ta-business'),
            'priority' => 7,
            'type' => 'select',
            'choices' => $ta_business_Category_list,
            'section' => 'ta_business_home_client_section'
        )
    );
    
    /** Contact Section **/
    $wp_customize->add_section(
        'ta_business_home_contact_section',
        array(
            'title'		=> esc_html__( 'contact Section', 'ta-business' ),
            'panel'     => 'ta_business_home_panel',
            'priority'  => 20,
        )
    );
    $wp_customize->add_setting(
        'ta_business_contact_enable_disable',
        array(
            'default' => 'disable',
            'sanitize_callback' => 'ta_business_sanitize_enable_disable',
            )
    );
    $wp_customize->add_control( new TA_Business_Customize_Switch_Control(
        $wp_customize, 
        'ta_business_contact_enable_disable', 
        array(
            'type' 		=> 'switch',
            'label' 	=> esc_html__( 'Enable / Disable contact Section', 'ta-business' ),
            'section' 	=> 'ta_business_home_contact_section',
            'choices'   => array(
                'enable' 	=> esc_html__( 'Enable', 'ta-business' ),
                'disable' 	=> esc_html__( 'Disable', 'ta-business' )
                ),
            'priority'  => 1,
        )
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_contact_form_section',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
    );
    $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_contact_form_section', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Contact Form Sections', 'ta-business' ),
                'section' 	=> 'ta_business_home_contact_section',
                'priority'  => 2,
            )	            	
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_contact_section_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_contact_section_title',
        array(
            'label' => esc_html__('Section Title','ta-business'),
            'priority' => 4,
            'type' => 'text',
            'section' => 'ta_business_home_contact_section'
        )
    );
    $wp_customize->add_setting(
        'ta_business_contact_section_sub_title',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
            'transport' => 'postMessage',
        )
    );
    $wp_customize->add_control(
        'ta_business_contact_section_sub_title',
        array(
            'label' => esc_html__('Section Sub Title','ta-business'),
            'priority' => 5,
            'type' => 'textarea',
            'section' => 'ta_business_home_contact_section'
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_contact_form_page',
        array(
            'default' => '',
            'sanitize_callback' => 'ta_business_sanitize_page_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_contact_form_page',
        array(
            'label' => esc_html__('contact Form Page','ta-business'),
            'priority' => 7,
            'type' => 'select',
            'choices' => $ta_business_Page_list,
            'section' => 'ta_business_home_contact_section'
        )
    );
   
    $wp_customize->add_setting(
        'ta_business_contact_map_section',
	        array(
	            'default' => '',
	            'sanitize_callback' => 'sanitize_text_field',
	        )
     );
     $wp_customize->add_control( new TA_Business_Customize_Section_Separator(
        $wp_customize, 
            'ta_business_contact_map_section', 
            array(
                'type' 		=> 'ta_business_separator',
                'label' 	=> esc_html__( 'Contact Map Sections', 'ta-business' ),
                'section' 	=> 'ta_business_home_contact_section',
                'priority'  => 10,
            )	            	
        )
     );
     
     $wp_customize->add_setting(
        'ta_business_contact_map_page',
        array(
            'default' => '',
            'sanitize_callback' => 'ta_business_sanitize_page_list',
        )
    );
    $wp_customize->add_control(
        'ta_business_contact_map_page',
        array(
            'label' => esc_html__('contact Map Page','ta-business'),
            'priority' => 12,
            'type' => 'select',
            'choices' => $ta_business_Page_list,
            'section' => 'ta_business_home_contact_section'
        )
    );
    
    /** Footer Text Section **/
    $wp_customize->add_section(
        'ta_business_footer_credit_section',
        array(
            'title'		=> esc_html__( 'Footer Section', 'ta-business' ),
            'priority'  => 20,
        )
    );
    
    $wp_customize->add_setting(
        'ta_business_footer_credit',
        array(
            'default' => '',
            'sanitize_callback' => 'sanitize_text_field',
        )
    );
    $wp_customize->add_control(
        'ta_business_footer_credit',
        array(
            'label' => esc_html__('Footer Text','ta-business'),
            'priority' => 4,
            'type' => 'text',
            'section' => 'ta_business_footer_credit_section'
        )
    );
}
add_action( 'customize_register', 'ta_business_customize_register' );

/** Customizer Class **/
if ( class_exists( 'WP_Customize_Control' ) ) {
    
    /** Switch Button **/
    class TA_Business_Customize_Switch_Control extends WP_Customize_Control {

		public $type = 'switch';

		public function render_content() {
	?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<div class="description customize-control-description"><?php echo esc_html( $this->description ); ?></div>
		        <div class="switch_button">
		        	<?php 
		        		$show_choices = $this->choices;
		        		foreach ( $show_choices as $key => $value ) {
		        			echo '<span class="switch_part '.esc_attr($key).'" data-switch="'.esc_attr($key).'">'. esc_attr($value).'</span>';
		        		}
		        	?>
                  	<input type="hidden" id="switch_button" <?php $this->link(); ?> value="<?php echo esc_attr($this->value()); ?>" />
                </div>
            </label>
	<?php
		}
	}
    
    /** Separator Class **/
	class TA_Business_Customize_Section_Separator extends WP_Customize_Control {
		
		public $type = 'ta_business_separator';

		public function render_content() {
	?>
		<div class="customize-section-wrap">
			<label>
				<span id="separator-customizer" class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
			</label>
		</div>
	<?php
		}
	}
    
    class TA_Business_Customize_FA_Icons_Control extends WP_Customize_Control {

		public $type = 'ta_business_fa_icons';

		public function render_content() {

			$saved_icon_value = $this->value();
	?>
			<label>
				<span class="customize-control-title"><?php echo esc_html( $this->label ); ?></span>
				<span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
				<div class="tab-fa-icons">
					<div class="tab-icon-preview"><?php if( !empty( $saved_icon_value ) ) { echo '<i class="fa '. esc_attr($saved_icon_value) .'"></i>'; } ?></div>
					<ul class="icons-list-wrapper">
						<?php 
							$ta_business_FA_icons = ta_business_FA_icons();
							foreach ( $ta_business_FA_icons as $ta_business_FA_icon ) {
						          echo '<li><i class="fa fa-'. esc_attr($ta_business_FA_icon) .'" aria-hidden="true"></i></li>';
							}
						?>
					</ul>
					<input type="hidden" class="tab-icon-value" value="" <?php esc_attr($this->link()); ?>>
				</div>

			</label>
	<?php
		}
	}
    
    /** Radio Image Control Class **/
    class TA_Business_Custom_Radio_Image_Control extends WP_Customize_Control {

    	public $type = 'radio-image';
    
    	public function render_content() {
    	   
    		if ( empty( $this->choices ) ) {
    			return;
    		}			
    		
    		$name = '_customize-radio-' . $this->id; ?>
            
    		<span class="customize-control-title">
    			<?php echo esc_attr( $this->label ); ?>
    			<?php if ( ! empty( $this->description ) ) : ?>
    				<span class="description customize-control-description"><?php echo esc_html( $this->description ); ?></span>
    			<?php endif; ?>
    		</span>
            
    		<div id="input_<?php echo esc_attr($this->id); ?>" class="image">
    			<?php foreach ( $this->choices as $value => $label ) : ?>
    				<input class="image-select" type="radio" value="<?php echo esc_attr( $value ); ?>" id="<?php echo esc_attr($this->id) . esc_attr($value); ?>" name="<?php echo esc_attr( $name ); ?>" <?php $this->link(); checked( $this->value(), $value ); ?>>
    					<label for="<?php echo esc_attr($this->id) . esc_attr($value); ?>">
    						<img src="<?php echo esc_html( $label ); ?>" alt="<?php echo esc_attr( $value ); ?>" title="<?php echo esc_attr( $value ); ?>">
    					</label>
    				</input>
    			<?php endforeach; ?>
    		</div>
            
   		<?php }
    }
    
}
    

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function ta_business_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function ta_business_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function ta_business_customize_preview_js() {
	wp_enqueue_script( 'ta-business-customizer', get_template_directory_uri() . '/inc/customizer/js/customizer.js', array( 'customize-preview' ), '20151215', true );
}
add_action( 'customize_preview_init', 'ta_business_customize_preview_js' );
