/**
 * File customizer.js.
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */

( function( $ ) {

	// Site title and description.
	wp.customize( 'blogname', function( value ) {
		value.bind( function( to ) {
			$( '.site-title a' ).text( to );
		} );
	} );
	wp.customize( 'blogdescription', function( value ) {
		value.bind( function( to ) {
			$( '.site-description' ).text( to );
		} );
	} );

	// Header text color.
	wp.customize( 'header_textcolor', function( value ) {
		value.bind( function( to ) {
			if ( 'blank' === to ) {
				$( '.site-title, .site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title, .site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a, .site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );
    
    wp.customize( 'ta_business_top_header_email', function( value ) {
		value.bind( function( to ) {
			$( '.tab-header-email span' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_top_header_phone', function( value ) {
		value.bind( function( to ) {
			$( '.tab-header-phone span' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_top_header_location', function( value ) {
		value.bind( function( to ) {
			$( '.tab-header-location span' ).text( to );
		} );
	} );
    
    
    wp.customize( 'ta_business_blog_section_title', function( value ) {
		value.bind( function( to ) {
			$( '#home-blog-section .tab-home-section-title h2' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_portfolio_section_title', function( value ) {
		value.bind( function( to ) {
			$( '#home-portfolio-section .tab-home-section-title h2' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_counter_section_title', function( value ) {
		value.bind( function( to ) {
			$( '#home-counter-section .tab-home-section-title h2' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_service_section_title', function( value ) {
		value.bind( function( to ) {
			$( '#home-service-section .tab-home-section-title h2' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_testimonial_section_title', function( value ) {
		value.bind( function( to ) {
			$( '#home-testimonial-section .tab-home-section-title h2' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_team_section_title', function( value ) {
		value.bind( function( to ) {
			$( '#home-team-section .tab-home-section-title h2' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_client_section_title', function( value ) {
		value.bind( function( to ) {
			$( '#home-client-section .tab-home-section-title h2' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_contact_section_title', function( value ) {
		value.bind( function( to ) {
			$( '#home-contact-section .tab-home-section-title h2' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_contact_section_sub_title', function( value ) {
		value.bind( function( to ) {
			$( '#home-contact-section .tab-home-section-title h4' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_counter_icon_one', function( value ) {
		value.bind( function( to ) {
            $( '#counter-home-one i' ).removeClass();
			$( '#counter-home-one i' ).addClass( 'fa '+to );
		} );
	} );
    
    wp.customize( 'ta_business_counter_title_one', function( value ) {
		value.bind( function( to ) {
			$( '#counter-home-one .counter-title h4' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_counter_count_one', function( value ) {
		value.bind( function( to ) {
			$( '#counter-home-one .counter-count span' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_counter_icon_two', function( value ) {
		value.bind( function( to ) {
            $( '#counter-home-two i' ).removeClass();
			$( '#counter-home-two i' ).addClass( 'fa '+to );
		} );
	} );
    
    wp.customize( 'ta_business_counter_title_two', function( value ) {
		value.bind( function( to ) {
			$( '#counter-home-two .counter-title h4' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_counter_count_two', function( value ) {
		value.bind( function( to ) {
			$( '#counter-home-two .counter-count span' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_counter_icon_three', function( value ) {
		value.bind( function( to ) {
            $( '#counter-home-three i' ).removeClass();
			$( '#counter-home-three i' ).addClass( 'fa '+to );
		} );
	} );
    
    wp.customize( 'ta_business_counter_title_three', function( value ) {
		value.bind( function( to ) {
			$( '#counter-home-three .counter-title h4' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_counter_count_three', function( value ) {
		value.bind( function( to ) {
			$( '#counter-home-three .counter-count span' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_counter_icon_four', function( value ) {
		value.bind( function( to ) {
            $( '#counter-home-four i' ).removeClass();
			$( '#counter-home-four i' ).addClass( 'fa '+to );
		} );
	} );
    
    wp.customize( 'ta_business_counter_title_four', function( value ) {
		value.bind( function( to ) {
			$( '#counter-home-four .counter-title h4' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_counter_count_four', function( value ) {
		value.bind( function( to ) {
			$( '#counter-home-four .counter-count span' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_countdown_form_title', function( value ) {
		value.bind( function( to ) {
			$( '.secondary-form h2' ).text( to );
		} );
	} );
    
     wp.customize( 'ta_business_countdown_title', function( value ) {
		value.bind( function( to ) {
			$( '.title-countdown h2' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_countdown_desc', function( value ) {
		value.bind( function( to ) {
			$( '.title-countdown h4' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_contact_section_title', function( value ) {
		value.bind( function( to ) {
			$( '.title-sub-contact h2' ).text( to );
		} );
	} );
    
    wp.customize( 'ta_business_contact_section_sub_title', function( value ) {
		value.bind( function( to ) {
			$( '.title-sub-contact p' ).text( to );
		} );
	} );
    
    
} )( jQuery );
